@@ -56,7 +56,7 @@ Data::Frame::Partial::Eval - Partial class for data frame's eval method
 
 =head1 VERSION
 
-version 0.0058
+version 0.0060
 
 =head1 SYNOPSIS
 
@@ -64,6 +64,9 @@ version 0.0058
 
 =head1 DESCRIPTION
 
+Do not use this module in your code. This is only internally used by
+L<Data::Frame>.
+
 The C<eval_tidy> method is similar to R's data frame tidy evaluation.
 
 =head1 METHODS
