@@ -15,20 +15,20 @@ with qw(PDL::Role::Stringifiable);
 requires 'levels';
 
 sub element_stringify_max_width {
-	my ($self, $element) = @_;
-	my @where_levels = @{ $self->{PDL}->uniq->unpdl };
-	my @which_levels = @{ $self->levels }[@where_levels];
-	my @lengths = map { length $_ } @which_levels;
-	List::AllUtils::max( @lengths );
+    my ($self, $element) = @_;
+    my @where_levels = @{ $self->{PDL}->uniq->unpdl };
+    my @which_levels = @{ $self->levels }[@where_levels];
+    my @lengths = map { length $_ } @which_levels;
+    List::AllUtils::max( @lengths );
 }
 
 sub element_stringify {
-	my ($self, $element) = @_;
-	$self->levels->[ $element ];
+    my ($self, $element) = @_;
+    $self->levels->[ $element ];
 }
 
 sub number_of_levels {
-	my ($self) = @_;
+    my ($self) = @_;
     return scalar( @{ $self->levels } );
 }
 
@@ -42,12 +42,16 @@ sub uniq {
 }
 
 around qw(slice dice) => sub {
-	my $orig = shift;
-	my ($self) = @_;
-	my $ret = $orig->(@_);
-	# TODO levels needs to be copied
-	$ret->levels( $self->levels );
-	$ret;
+    my $orig = shift;
+    my $self = shift;
+    my $class = ref($self);
+
+    my $pdl = $self->{PDL}->$orig(@_);
+    my $ret = bless( { PDL => $pdl }, $class );
+
+    # TODO levels needs to be copied
+    $ret->levels( $self->levels );
+    return $ret;
 };
 
 1;
@@ -64,7 +68,7 @@ PDL::Role::Enumerable
 
 =head1 VERSION
 
-version 0.0058
+version 0.0060
 
 =head1 AUTHORS
 
